@@ -36,7 +36,6 @@ def normalize_signal(signal : np.ndarray,
        Two normalization method can be used. ``'F'`` is the standard :math:`\\frac{\\Delta F}{F_0}`.
        ``'Z'`` is the z-score difference of signal and control.
     """
-
     if method == 'F':
         coeff = np.polynomial.polynomial.polyfit(control, signal, 1)
         fitted_control = coeff[0] + control*coeff[1]
@@ -48,8 +47,9 @@ def normalize_signal(signal : np.ndarray,
     return normalized
 
 
-def detect_peaks(time : np.ndarray,
-                 signal : np.ndarray, 
+def detect_peaks(arr=[],
+                 time=[],
+                 signal=[], 
                  window :  float = 10,
                  distance : str = '50ms',
                  plot : bool =True,
@@ -57,6 +57,8 @@ def detect_peaks(time : np.ndarray,
                  zscore : str ='full',
                  bMAD : float = 2.5,
                  pMAD : float = 3.5,
+                 xlim : Union[bool, tuple] = False,
+	         save : Union[bool, str] = False,
                  **kwargs):
     """Detect peaks in a normalized fiberphotometry signal.
 
@@ -78,6 +80,13 @@ def detect_peaks(time : np.ndarray,
        Additionnally, any keyword argument catched by **kwargs** is passed to ``find_peaks`` so more precise criteria
        can be used.
     """     
+    if (not len(arr)) and ((not len(signal)) or (not len(time))):
+        return
+    elif len(arr):
+        time = arr[:,0]
+        signal = arr[:,1]
+    else:
+        pass
     dF = signal.copy()
     # calculate zscores
     if zscore == 'full':
@@ -110,15 +119,15 @@ def detect_peaks(time : np.ndarray,
     if zscore == 'bins':
         bins = [(b - b.mean())/b.std() for b in bins]
 
-    # find median for each bin and remove events >2MAD for baselines
+    # find median for each bin and remove events >(bMAD)*MAD for baselines
     baselines = [
         b[b < np.median(b) + bMAD*np.median(abs(b - np.median(b)))]
         for b in bins
                 ]
 
-    # calculate peak tresholds for each bin, by default >3MAD of previously created baseline
+    # calculate peak tresholds for each bin, by default >(pMAD)*MAD of previously created baseline
     tresholds = [
-        np.median(b)+pMAD*np.median(abs(b-np.median(b)))
+        np.median(b) + pMAD * np.median(abs(b - np.median(b)))
         for b in baselines
                 ]
 
@@ -155,21 +164,28 @@ def detect_peaks(time : np.ndarray,
             c = random.choice(list('bgrcmy'))
             plt.plot(i, alpha=0.6, color=c)
             plt.plot(baselines[n],
-                     color=c,
-                     label=n * '_'+'signal <2MAD + median') # keeps only the first label
+                     color='gray',
+                     alpha=0.5,
+                     label=n * '_'+f'signal <{bMAD}MAD + median') # keeps only the first label
             plt.plot(bin_medians[n],
                      color='k',
                      label=n*'_'+'signal median')
-            plt.plot(bin_medians[n]+bin_mad[n]*2,
+            plt.plot(bin_medians[n]+bin_mad[n]*bMAD,
                      color='darkgray',
-                     label=n*'_'+'>2MAD + median')
+                     label=n*'_'+f'>{bMAD}MAD + median')
             plt.plot(peak_tresholds[n],
                      color='r',
-                     label=n*'_'+'>3MAD + baseline')
+                     label=n*'_'+f'>{pMAD}MAD + baseline')
         for n, p in enumerate(peaks):
             plt.scatter(p.loc[:, 'time'],
                         p.loc[:, 'zscore'])
+        if xlim:
+            plt.xlim(xlim) 
         plt.legend()
+        if save:
+            plt.savefig(f"{save}.pdf")
+            plt.savefig(f"{save}.png", dpi=600)
+        plt.show()
     return pd.concat(peaks, ignore_index=True)
 
 
@@ -300,7 +316,7 @@ class Fiber(PyFiber):
             data = self.norm(rec=r, add_time=True)
             t = data[:, 0]
             s = data[:, 1]
-            self.peaks[r] = self._detect_peaks(t, s, plot=False)
+            self.peaks[r] = self._detect_peaks(time=t, signal=s, plot=False)
         
         self._print(
             f'Importing of {filepath} finished in {time.time() - start} seconds')
@@ -523,8 +539,10 @@ Aligned to behavior file : {self.alignment} s
             return normalized
 
     def _detect_peaks(self,
-                      t : np.ndarray,
-                      s : np.ndarray, 
+                      rec=False,
+                      arr=[],
+                      time=[],
+                      signal=[], 
                       window : Union[str,float] ='default',
                       distance : str ='default',
                       plot : bool =True,
@@ -536,6 +554,7 @@ Aligned to behavior file : {self.alignment} s
         """Detect peaks in a normalized fiberphotometry signal.
 
         API for ``fiber.detect_peaks``, with class default.
+        :param arr: numpy array with timestamps in first column and signal values in second column
         :param time: timestamps
         :param signal: fiber photometry signal
         :param window: size of each succesive bins were peaks are computed (default is 10s)
@@ -568,9 +587,11 @@ Aligned to behavior file : {self.alignment} s
             pMAD = int(self.peak_peak_MAD)
         else:
             pMAD = int(pMAD)
-
-        df = detect_peaks(signal=s,
-                          time=t,
+        if rec:
+            arr = self.norm(rec)
+        df = detect_peaks(arr=arr,
+                          signal=signal,
+                          time=time,
                           distance=distance,
                           window=window,
                           plot=plot,
